@@ -1,7 +1,7 @@
 #############################################################################
 #   $Author: markus $
-#     $Date: 2008-07-26 03:16:07 +0200 (Sat, 26 Jul 2008) $
-# $Revision: 809 $
+#     $Date: 2008-08-19 18:12:28 +0200 (Tue, 19 Aug 2008) $
+# $Revision: 826 $
 #############################################################################
 
 package LaTeX::Table;
@@ -10,7 +10,7 @@ use 5.008;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv('0.6.3');
+use version; our $VERSION = qv('0.7.0');
 
 use Carp;
 use Fatal qw( open close );
@@ -876,6 +876,11 @@ EOST
                 'HORIZONTAL_LINES'   => [ 0, 1, 0 ],
                 'BOOKTABS'           => 0,
             },
+            'plain' => {
+                'VERTICAL_LINES'     => [ 0, 0, 0 ],
+                'HORIZONTAL_LINES'   => [ 0, 0, 0 ],
+                'BOOKTABS'           => 0,
+            },
         };
         return;
     }
@@ -930,7 +935,7 @@ LaTeX::Table - Perl extension for the automatic generation of LaTeX tables.
 
 =head1 VERSION
 
-This document describes LaTeX::Table version 0.6.3
+This document describes LaTeX::Table version 0.7.0
 
 =head1 SYNOPSIS
 
@@ -956,7 +961,7 @@ This document describes LaTeX::Table version 0.6.3
         filename    => 'prices.tex',
         maincaption => 'Price List',
         caption     => 'Try our special offer today!',
-        label       => 'table_prices',
+        label       => 'table:prices',
         tablepos    => 'htb',
         header      => $header,
         data        => $data,
@@ -994,7 +999,8 @@ Now in your LaTeX document:
 
 LaTeX::Table provides functionality for an intuitive and easy generation of
 LaTeX tables for reports or theses. It ships with some predefined good looking
-table styles. Supports multipage tables via the xtab package. 
+table styles. Supports multipage tables via the xtab package and publication
+quality tables with the booktabs package. 
 
 =head1 INTERFACE 
 
@@ -1010,12 +1016,12 @@ options (see below).
 Generates the LaTeX table code. The generated LaTeX table can be included in
 a LaTeX document with the C<\input> command:
   
-  % include counter.tex, generated by LaTeX::Table 
-  \input{counter}
+  % include prices.tex, generated by LaTeX::Table 
+  \input{prices}
 
 =item C<$table-E<gt>generate_string()>
 
-Same as generate() but does not create a LaTeX file but returns the LaTeX code
+Same as generate() but instead of creating a LaTeX file, this returns the LaTeX code
 as string.
 
   my $latexcode = $table->generate_string();
@@ -1059,51 +1065,76 @@ I<std>.
 The header. It is a reference to an array (the rows) of array references (the
 columns).
 
-  $table->set_header([ [ 'Name', 'Beers' ] ]);
+  $table->set_header([ [ 'Animal', 'Price' ] ]);
 
 will produce following header:
 
-  +------+-------+
-  | Name | Beers |
-  +------+-------+
+  +--------+-------+
+  | Animal | Price |
+  +--------+-------+
 
 Here an example for a multirow header:
 
-  $table->set_header([ [ 'Name', 'Beers' ], ['', '(roughly)' ] ]);
+  $table->set_header([ [ 'Animal', 'Price' ], ['', '(roughly)' ] ]);
 
 This code will produce this header:
 
-  +------+-----------+
-  | Name |   Beers   |
-  |      | (roughly) |
-  +------+-----------+
+  +--------+-----------+
+  | Animal |   Price   |
+  |        | (roughly) |
+  +--------+-----------+
+
+Single column rows that start with a backslash are treated as LaTeX commands
+and are not further formatted. So,
+
+  my $header = [
+      [ 'Item:2c', '' ],
+      ['\cline{1-2}'],
+      [ 'Animal', 'Description', 'Price' ]
+  ];
+
+will produce following LaTeX code in the default Zurich theme:
+
+  \multicolumn{2}{c}{\textbf{Item}} & \multicolumn{1}{c}{\textbf{}}\\ 
+  \cline{1-2}
+  \multicolumn{1}{c}{\textbf{Animal}} & \multicolumn{1}{c}{\textbf{Description}} & \multicolumn{1}{c}{\textbf{Price}}\\ 
+
+Note that there is no multicolum, textbf, & or \\ added to the second row.
 
 =item C<data>
 
 The data. Once again a reference to an array (rows) of array references
 (columns). 
 
-  $table->set_data([ [ 'Marge', '1' ], [ 'Homer', '4' ] ]);
+  $table->set_data([ [ 'Gnu', '92.59' ], [ 'Emu', '33.33' ] ]);
 
 And you will get a table like this:
 
  +-------+---------+
- | Marge |       1 |
- | Homer |       4 |
+ | Gnu   |   92.59 |
+ | Emu   |   33.33 |
  +-------+---------+
 
 An empty column array will produce a horizontal line:
 
-  $table->set_data([ [ 'Marge', '1' ], [], [ 'Homer', '4' ] ]);
+  $table->set_data([ [ 'Gnu', '92.59' ], [], [ 'Emu', '33.33' ] ]);
 
 And you will get a table like this:
 
  +-------+---------+
- | Marge |       1 |
+ | Gnu   |   92.59 |
  +-------+---------+
- | Homer |       4 |
+ | Emu   |   33.33 |
  +-------+---------+
 
+Single column rows starting with a backslash are again printed without any
+formatting. So,
+
+  $table->set_data([ [ 'Gnu', '92.59' ], ['\hline'], [ 'Emu', '33.33' ] ]);
+
+is equivalent to the example above (except that there always the correct line
+command is used, i.e. C<\midrule> vs. C<\hline>).
+
 =back
 
 =head2 TABLE ENVIRONMENT
@@ -1117,11 +1148,11 @@ affects tables of C<type> I<std>.
 
     \begin{table}[htb]
         \center
-        \begin{tabular}{|l||r|r|}
+        \begin{tabular}{lrr}
         ...
         \end{tabular}
-        \caption{Number of beers}
-        \label{table_beercounter}
+        \caption{Price list}
+        \label{table:prices}
     \end{table} 
 
 =item C<caption>
@@ -1166,8 +1197,11 @@ returns a true value. Requires C<table_environment>.
 =item C<callback>
 
 If get_callback() returns a true value and the return value is a code reference,
-then this callback function will be called for every column. The passed
-arguments are C<$row>, C<$col> (both starting with 0), C<$value> and 
+then this callback function will be called for every column in C<header>
+and C<data>. The return value of this function is then printed instead of the 
+column value.
+
+The passed arguments are C<$row>, C<$col> (both starting with 0), C<$value> and 
 C<$is_header>.
 
    use LaTeX::Encode;
@@ -1190,7 +1224,12 @@ C<$is_header>.
 
 =item C<tabledef>
 
-The table definition, e.g. C<|l|r|c|r|>. If unset, C<LaTeX::Table> tries to 
+The table definition, e.g. C<lrcr> which would result in:
+
+  \begin{tabular}{lrcr}
+  ..
+
+If unset, C<LaTeX::Table> tries to 
 guess a good definition. Columns containing only numbers are right-justified,
 others left-justified. Columns with cells longer than 50 characters are
 I<paragraph> columns of size 5 cm. These rules can be changed with
@@ -1234,7 +1273,7 @@ Default 'l' (left-justified).
 Example:
 
   $table->set_tabledef_strategy({
-    IS_A_NUMBER => qr{\A \d+ \z}xms, # integers only;
+    IS_A_NUMBER => qr{\A \d+ \z}xms, # integers only
     IS_LONG     => 60, # min. 60 characters
     LONG_COL    => 'm{7cm}', # vertically aligned at the middle, 7cm
   });
@@ -1318,71 +1357,14 @@ C<|c|> overrides the LINES settings in the theme (See L<"CUSTOM THEMES">).
 =head1 THEMES
 
 The theme can be selected with C<$table-E<gt>set_theme($themename)>. 
-Currently, following predefined themes are available: I<Zurich>, I<Dresden>, 
-I<Berlin>, I<Miami> and I<Houston>. The script F<generate_examples.pl> in the 
+Currently, following predefined themes are available: I<Zurich>, I<plain> (no
+formatting), I<Dresden>, I<Berlin>, I<Miami> and I<Houston>. The script F<generate_examples.pl> in the 
 I<examples> directory of this distributions generates some examples for all 
 available themes.
 
-=head2 ZURICH
-
-The default theme. Requires C<\usepackage{booktabs}> in your LaTeX document.
-The top and bottom lines are slightly heavier (ie thicker, or darker) than the
-other lines. No vertical lines.
-
-  ------------------------
-    Name     Beer   Wine  
-  ------------------------
-    Marge       1      0  
-    Homer       4      0  
-  ------------------------
-
-=head2 DRESDEN
-
-Nice and clean, with a centered header written in bold text. Header
-and first column are separated by a double line.
-
-  +-------++------+------+
-  | Name  || Beer | Wine |
-  +-------++------+------+
-  +-------++------+------+
-  | Marge ||    1 |    0 |
-  | Homer ||    4 |    0 |
-  +-------++------+------+
-
-=head2 BERLIN
-
-First column separated by only one line.
-
-  +-------+------+------+
-  | Name  | Beer | Wine |
-  +-------+------+------+
-  +-------+------+------+
-  | Marge |    1 |    0 |
-  | Homer |    4 |    0 |
-  +-------+------+------+
- 
-=head2 HOUSTON
-
-Very similar to I<Dresden>, but columns are separated (one inner line).
-
-  +-------++------+------+
-  | Name  || Beer | Wine |
-  +-------++------+------+
-  +-------++------+------+
-  | Marge ||    1 |    0 |
-  +-------++------+------+
-  | Homer ||    4 |    0 |
-  +-------++------+------+
-
-=head2 MIAMI
-
-A very simple theme. Header once again written in bold text.
-
-    Name    Beer   Wine
-  -----------------------
-    Marge      1      0
-    Homer      4      0
-
+The default theme, Zurich, is highly recommended. It requires C<\usepackage{booktabs}> in 
+your LaTeX document. The top and bottom lines are slightly heavier (ie thicker, or darker) than the
+other lines. No vertical lines. You want this. Believe it.
 
 =head2 CUSTOM THEMES
 
@@ -1440,8 +1422,9 @@ Valid values are 0 (not centered) or 1 (centered).
 
 =item C<BOOKTABS>
 
-Use the Booktabs package for "Publication quality tables". 0 (don't use this
-package) or 1 (use it).
+Use the Booktabs package for "Publication quality tables". Instead of
+C<\hline>, C<LaTeX::Table> then uses C<\toprule>, C<\midrule> and C<\bottomrule>. 
+0 (don't use this package) or 1 (use it).
 
 =back
 
@@ -1451,32 +1434,29 @@ package) or 1 (use it).
 
 =over
 
-=item callback is not a code reference 
+=item C<callback> is not a code reference 
 
-The return value of get_callback() is not a code reference. See 
+The return value of C<get_callback()> is not a code reference. See 
 L<"TABULAR ENVIRONMENT">.
 
-=item data/header is not an array reference 
+=item C<data/header> is not an array reference 
 
 get_data() (or get_header(), respectively) does not return a 
 reference to an array. See L<"BASIC OPTIONS">.
 
-=item data[$i]/header[$i] is not an array reference
+=item C<data[$i]/header[$i]> is not an array reference
 
 The ith element of get_data() (or get_header()) is not an array reference. See L<"BASIC OPTIONS">.
 
-
-=item data[$i][$j]/header[$i][$j] is not a scalar
+=item C<data[$i][$j]/header[$i][$j]> is not a scalar
 
 The jth column in the ith row is not a scalar. See L<"BASIC OPTIONS">.
 
-
-=item DEPRECATED. Use options header and data instead.
+=item DEPRECATED. Use options C<header> and C<data> instead.
 
 You have called either generate() or generate_string() with header and data as
 parameters. This is deprecated since C<LaTeX::Table> 0.1.0.  See L<"BASIC OPTIONS">.
 
-
 =item Family not known: ... . Valid families are: ...
 
 You have set a font family to an invalid value. See L<"CUSTOM THEMES">.
@@ -1485,12 +1465,12 @@ You have set a font family to an invalid value. See L<"CUSTOM THEMES">.
 
 You have set a font size to an invalid value. See L<"CUSTOM THEMES">.
 
-=item tabledef_strategy not a hash reference.
+=item C<tabledef_strategy> not a hash reference.
 
 The return value of get_tabledef_strategy() is not a hash reference. See 
 L<"TABULAR ENVIRONMENT">.
 
-=item text_wrap is not an array reference
+=item C<text_wrap> is not an array reference
 
 The return value of get_text_wrap() is not an array reference. See
 L<"TABULAR ENVIRONMENT">.
@@ -1499,18 +1479,17 @@ L<"TABULAR ENVIRONMENT">.
 
 You have set the option C<theme> to an invalid value. See L<"THEMES">.
 
-=item Undefined value in data[$i][$j]/header[$i][$j]
+=item Undefined value in C<data[$i][$j]/header[$i][$j]>
 
 The value in this cell is C<undef>. See L<"BASIC OPTIONS">.
 
-=item Value in text_wrap not an integer: ...
+=item Value in C<text_wrap> not an integer: ...
 
 All values in the text_wrap array reference must either be C<undef> or must 
 match the regular expression C<m{\A \d+ \z}xms>. See 
 L<"TABULAR ENVIRONMENT">.
 
-
-=item xentrystretch not a number
+=item C<xentrystretch> not a number
 
 You have set the option C<xentrystretch> to an invalid value. This option
 requires a number. See L<"MULTIPAGE TABLES">.
@@ -1524,7 +1503,7 @@ C<LaTeX::Table> requires no configuration files or environment variables.
 =head1 DEPENDENCIES
 
 L<Carp>, L<Class::Std>, L<English>,
-L<Fatal>, L<Scalar::Util>, L<Text::Wrap>
+L<Fatal>, L<Readonly>, L<Scalar::Util>, L<Text::Wrap>
 
 =head1 INCOMPATIBILITIES
 
@@ -1542,6 +1521,10 @@ L<http://rt.cpan.org>.
 
 L<Data::Table>, L<LaTeX::Encode>
 
+=head1 CREDITS
+
+Andrew Ford (ANDREWF): many great suggestions.
+
 =head1 AUTHOR
 
 Markus Riester  C<< <mriester@gmx.de> >>
